#!/bin/ksh

# PTF Advance Edition Install

echo "WebSphere Application Server 3.5, Advanced Edition PTF 7"
echo "Please shut down the Application Server and any Webservers that might be running"
echo "If not the PTF may not be installed properly"
echo "If you want to install silently, please issue install.sh -silent"

SILENT_INSTALL="false"
IGNORE_ERRORS="false"

OS_NAME=`uname`

if [[ "$IHS_INSTALL" != "false" ]] ; then
	IHS_INSTALL="true"
fi

JDK_INSTALL="true"

if [[ "$OS_NAME" = "AIX" ]]  ; then
   IHS_DIR="/usr/HTTPServer"
   EXAMPLE_DOC_ROOT=$IHS_DIR/htdocs/en_US
elif [[ "$OS_NAME" = "SunOS" || "$OS_NAME" = "Solaris" ]] ; then
   IHS_DIR="/opt/IBMHTTPD"
   EXAMPLE_DOC_ROOT=$IHS_DIR/htdocs
elif [[ "$OS_NAME" = "HP-UX" ]]  ; then
   IHS_DIR="/opt/HTTPServer"
   EXAMPLE_DOC_ROOT=$IHS_DIR/htdocs
elif [[ "$OS_NAME" = "Linux" ]]  ; then
   IHS_DIR="/opt/IBMHTTPServer"
   EXAMPLE_DOC_ROOT="$IHS_DIR/htdocs/en_US"
   # get currently installed GSkit
   GS_VERSION=`rpm -qa | grep gsk4bas`
   export LD_ASSUME_KERNEL=2.2.5
else
   echo "Unsupported platform: $OS_NAME"
   echo "Exiting ..."
   exit 1
fi

# Check for ignore errors option
if [[ "$1" = "-ignore" || "$2" = "-ignore" ]] ; then
    IGNORE_ERRORS="true"
    echo ""
    echo "You have chosen to let the ptf install ignore the errors thrown"
    echo "during the install. It is recommended to use this option (-ignore)"
    echo "only when the ptf will be installed on a machine that does not"
    echo "have a full WebSphere installation (example: IHS and plugin"
    echo "only config)."
    echo ""
fi

# Check for silent install
if [[ "$1" = "-silent" || "$2" = "-silent" ]] ; then 
   if [[ "$WAS_DIR" = "" ]] ; then
      echo ""
      echo "Please set all of the following environment variables."
      echo "WAS_DIR : Set it to the WebSphere root directory ( eg: /usr/WebSphere/AppServer )"
      echo "IHS_INSTALL : Set it to true if you want to install IHS PTF, else false"
      echo "DOC_ROOT : Set this to WebServer's Doc root only if you want to upgrade Samples"
      echo "IPLANET_HOME : Set this to the configuration directory of the"
      echo "               Sun ONE Web Server (iPlanet).  Leave this empty if it is not installed."
      echo "               (Example: /usr/iplanet/servers/https-<hostname>/config)"
      echo "IPLANET_VERSION : Set this to the version number of the Sun ONE Web Server (iPlanet)"
      echo "                  that is to be configured.  Leave this empty if it is not installed."
      echo "                  (Valid values are 4 or 6)"
      
      exit 1
   else 
      SILENT_INSTALL="true"
   fi   
fi

if [[ "$SILENT_INSTALL" = "true" ]] ; then
   echo "Installing PTF silently"
fi

DELTA_JAR="was35_adv_ptf_7.jar"
DELTA_LOG="was35_adv_ptf_7.log"
## defect 110215 updating to ihs ptf 5
IHS_PTF="ihs_ptf_7.jar"
IHS_BACKUP_JAR="ihs_ptf_7_backup.jar"
IHS_LOG_FILE="ihs_ptf_7.log"
##
JAVA_PTF="jdk_ptf_7.jar"
BACKUP_JAR="was35_ptf_7_backup.jar"
JAVA_BACKUP_JAR="jdk_ptf_7_backup.jar"
UINSTALL_FILE="uninstall_ptf_7.sh"
LOG_FILE="was35_ptf_7.log"
JAVA_LOG_FILE="jdk_ptf_7.log"

##  echo "OS_NAME      = $OS_NAME"
##  echo "DELTA_JAR    = $DELTA_JAR"
##  echo "DELTA_LOG    = $DELTA_LOG"
##  echo "IHS_PTF      = $IHS_PTF"
##  echo "JAVA_PTF     = $JAVA_PTF"
##  echo "IHS_DIR      = $IHS_DIR"

 if [[ "$SILENT_INSTALL" = "false" ]] ; then
   while :
   do
   {
    echo "Please enter the WebSphere root directory"
    read WAS_DIR
    if [[ "${WAS_DIR}" = "" ]]
    then
       continue
    fi
      
    if [[ ! -d ${WAS_DIR} || ! -f ${WAS_DIR}/properties/com/ibm/websphere/product.xml  ]]
       then
         {
            echo
            echo "Unable to locate file: ${WAS_DIR}/properties/com/ibm/websphere/product.xml"
            echo 
            continue
         }
     fi

     break
    }
    done
 fi

#Set the JAVA_HOME and PATH 
export JAVA_HOME=$WAS_DIR/java
if [[ "$OS_NAME" = "AIX" ]]  ; then
  export PATH=$JAVA_HOME/jre/sh:$JAVA_HOME/sh:$PATH
elif [[ "$OS_NAME" = "SunOS" || "$OS_NAME" = "Solaris" ]] ; then
  export PATH=$JAVA_HOME/bin:$PATH
elif [[ "$OS_NAME" = "HP-UX" ]]  ; then
  export PATH=$JAVA_HOME/bin:/usr/sbin:$PATH
elif [[ "$OS_NAME" = "Linux" ]]  ; then  
   #Make sure the link is in place.
   if [[ ! -L $WAS_DIR/java ]] ; then
      #If not, make it in place, JDK should be in two possible spots.
      if [[ -d $WAS_DIR/IBMJava2-122 ]] ; then
	ln -s /$WAS_DIR/IBMJava2-122/ $WAS_DIR/java
      elif [[ -d /opt/IBMJava2-122 ]] ; then
	ln -s /opt/IBMJava2-122/ $WAS_DIR/java
      else
	while :
	do
	{
        echo "Please enter your IBM-jdk directory."
	echo "Example: /opt/IBMJava2-122"
	  read JDK_DIR
	  if [[ ! -f $JDK_DIR/bin/java ]]
	  then
             echo "This does not appear to be a valid IBM-jdk."
             continue
	  fi
  
	  break
	}
	done
        ln -s $JDK_DIR $WAS_DIR/java
      fi
   fi 
  export PATH=$JAVA_HOME/bin:$PATH
fi


#Installing the WAS PTF
echo "Installing the WebSphere Application Server 3.5 PTF 7"

if [[ "$SILENT_INSTALL" = "true" ]] ; then
   java -jar $DELTA_JAR -TargetDir $WAS_DIR -backupJar $WAS_DIR/$BACKUP_JAR -log $WAS_DIR/logs/$LOG_FILE -OverWriteBackupJar
else
   java -jar $DELTA_JAR -TargetDir $WAS_DIR -backupJar $WAS_DIR/$BACKUP_JAR -log $WAS_DIR/logs/$LOG_FILE
fi

if [[ "$IGNORE_ERRORS" = "false" && $? -ne 0 ]] ; then
   echo "Either the user has chosen to exit, or there was an error "
   echo "during the WebSphere PTF upgrade." 
   echo "In case of error, run uninstall_ptf_#.sh to back out the changes."
   exit
fi

#if [[ "$OS_NAME" = "HP-UX" ]]  ; then
#   chmod 755 $WAS_DIR/bin/libioser12*
#fi


#Installing the JDK PTF
if [[ "$JDK_INSTALL" = "true" ]] ; then
  echo "Installing JDK PTF 7"
  JAVA_PTF_DIR=$WAS_DIR/java_ptf_7
  mkdir $JAVA_PTF_DIR

  if [[ "$OS_NAME" = "Linux" ]]  ; then
     cp -Rfd $JAVA_HOME/* $JAVA_PTF_DIR/
  else
     cp -R $JAVA_HOME/* $JAVA_PTF_DIR/
  fi

if [[ "$SILENT_INSTALL" = "true" ]] ; then
   java -jar $JAVA_PTF -TargetDir $JAVA_PTF_DIR -backupJar $WAS_DIR/$JAVA_BACKUP_JAR -log $WAS_DIR/logs/$JAVA_LOG_FILE -SkipVer -OverWriteBackupJar
else
   java -jar $JAVA_PTF -TargetDir $JAVA_PTF_DIR -backupJar $WAS_DIR/$JAVA_BACKUP_JAR -log $WAS_DIR/logs/$JAVA_LOG_FILE -SkipVer
fi

   if [[ $? -ne 0 ]] ; then
      echo "Either the user has chosen to exit, or there was an error "
      echo "during the JDK PTF upgrade."
      echo "In case of error, run uninstall_ptf_#.sh to back out the changes."
      exit
   fi

  if [[ "$OS_NAME" = "AIX" ]] ; then
      slibclean
  fi
  sleep 5
  rm -rf $JAVA_HOME/*

  if [[ "$OS_NAME" = "Linux" ]]  ; then
     cp -Rfd $JAVA_PTF_DIR/* $JAVA_HOME/
  else
     cp -R $JAVA_PTF_DIR/* $JAVA_HOME/
  fi

  rm -rf $JAVA_PTF_DIR
  if [[ "$OS_NAME" = "HP-UX" ]] ; then
     chmod -R 755 $JAVA_HOME/jre/lib/PA_RISC/*
     chmod -R 755 $JAVA_HOME/jre/lib/PA_RISC2.0/*
     chmod 755 $JAVA_HOME/jre/bin/.start_xfs
     chmod 755 $JAVA_HOME/bin/.start_xfs
     chmod 755 $JAVA_HOME/bin/PA_RISC/native_threads/.start_xfs
     chmod 755 $JAVA_HOME/bin/PA_RISC2.0/native_threads/.start_xfs
     chmod 755 $JAVA_HOME/jre/bin/PA_RISC/native_threads/.start_xfs
     chmod 755 $JAVA_HOME/jre/bin/PA_RISC2.0/native_threads/.start_xfs
  elif [[ "$OS_NAME" = "SunOS" || "$OS_NAME" = "Solaris" ]] ; then
     chmod -R 755 $JAVA_HOME/jre/lib/sparc/*
  fi
fi


# Section for handling dection of iPlanet web server update.

case "$OS_NAME" in
SunOS|Solaris|HP-UX|AIX)
    echo "WebSphere Application Server 3.5.7 supports"
    echo "Sun ONE Web Server (formerly iPlanet) versions 4.x.x"
    echo "and 6.0.x.  In order for the WebSphere plugin to work"
    echo "properly with the Sun ONE Web Server (iPlanet) certain"
    echo "changes must be made to the configuration file(s) depending"
    echo "on the Web Server version that is installed."
    echo
    echo "By agreeing to update the Sun ONE Web Server (iPlanet)"
    echo "configuration files will result in the PTF installer"
    echo "configuring the Sun ONE Web Server (iPlanet) to use the"
    echo "WebSphere plugin even if the plugin was not installed"
    echo "during the base WebSphere Application Server 3.5.0"
    echo "installation."
    echo
    
    if [[ "$SILENT_INSTALL" = "true" ]] ; then
    
        echo "Since this is a silent installation of the PTF, the"
        echo "installer will now check the environment variables"
        echo "IPLANET_HOME and IPLANET_VERSION to see if they are"
        echo "set properly."
        echo

        if [[ "$IPLANET_HOME" = "" ]] ; then
            echo
            echo "The environment variable IPLANET_HOME is null and"
            echo "this is a silent install, therefore the installer"
            echo "will not attempt to make changes to the Sun ONE Web Server (iPlanet)"
            echo "configuration."
            echo
            IPLANET=
        fi;
        
        if [[ "$IPLANET_VERSION" = "" ]] ; then
            echo
            echo "The environment variable IPLANET_VERSION is null and"
            echo "this is a silent install, therefore the installer"
            echo "will not attempt to make changes to the Sun ONE Web Server (iPlanet)"
            echo "configuration."
            echo
            IPLANET=
        fi;
            
        if [[ "$IPLANET_HOME" != "" && "$IPLANET_VERSION" != "" ]] ; then
                echo "IPLANET_HOME and IPLANET_VERSION are not null."
                echo "The installer will now validate their values."
                echo

                if [[ ! -f "$IPLANET_HOME/obj.conf" ]] ; then
                    echo "The path for the environment variable IPLANET_HOME"
                    echo "does not exist."
                    echo "[$IPLANET_HOME]"
                    echo "No Sun ONE Web Server (iPlanet) changes will be made."
                    echo
                    IPLANET=
                else
                    if [[ "$IPLANET_VERSION" = "4" ]] ; then
                        echo "The path specified in 'IPLANET_HOME' exists"
                        echo "and the value specified in 'IPLANET_VERSION' is valid,"
                        echo "therefore the Sun ONE Web Server (iPlanet) configuration"
                        echo "update will occur."
                        echo "IPLANET_HOME: $IPLANET_HOME"
                        echo "IPLANET_VERSION: $IPLANET_VERSION"
                        echo
                        
                        IPLANET="$WAS_DIR $IPLANET_HOME $IPLANET_VERSION true"
                        
                        if [[ ! -f "$WAS_DIR/IPlanet6Support.class" ]] ; then
                           if [[ ! -f "was35_adv_ptf_7.jar" ]] ; then
                              echo "The was35_adv_ptf_7.jar file must be in the same directory as the install.sh file."
                              echo
                           else
                              echo "Extracting IPlanet6Support.class"
                              echo
                              jar -xf was35_adv_ptf_7.jar IPlanet6Support.class
                              cp "IPlanet6Support.class" "$WAS_DIR/IPlanet6Support.class"
                              java -classpath $WAS_DIR IPlanet6Support $IPLANET
                              rm -f $WAS_DIR/IPlanet6Support.class
                           fi;
                        else
                           java -classpath $WAS_DIR IPlanet6Support $IPLANET
                           rm -f $WAS_DIR/IPlanet6Support.class
                        fi;
                        
                    elif [[ "$IPLANET_VERSION" = "6" ]] ; then
                        echo "The path specified in 'IPLANET_HOME' exists"
                        echo "and the value specified in 'IPLANET_VERSION' is valid,"
                        echo "therefore the Sun ONE Web Server (iPlanet) configuration"
                        echo "update will occur."
                        echo "IPLANET_HOME: $IPLANET_HOME"
                        echo "IPLANET_VERSION: $IPLANET_VERSION"
                        echo
                        
                        IPLANET="$WAS_DIR $IPLANET_HOME $IPLANET_VERSION true"
                        
                        if [[ ! -f "$WAS_DIR/IPlanet6Support.class" ]] ; then
                           if [[ ! -f "was35_adv_ptf_7.jar" ]] ; then
                              echo "The was35_adv_ptf_7.jar file must be in the same directory as the install.sh file."
                              echo
                           else
                              echo "Extracting IPlanet6Support.class"
                              echo
                              jar -xf was35_adv_ptf_7.jar IPlanet6Support.class
                              cp "IPlanet6Support.class" "$WAS_DIR/IPlanet6Support.class"
                              java -classpath $WAS_DIR IPlanet6Support $IPLANET
                              rm -f $WAS_DIR/IPlanet6Support.class
                           fi;
                        else
                           java -classpath $WAS_DIR IPlanet6Support $IPLANET
                           rm -f $WAS_DIR/IPlanet6Support.class
                        fi;
                    else
                        echo
                        echo "The value specified for environment IPLANET_VERSION is"
                        echo "not 4 or 6.  Please change the environment according to"
                        echo "the version of Sun ONE Web Server (iPlanet) you have installed."
                        echo "The Sun ONE Web Server (iPlanet) changes will not be made."
                        echo
                    fi;
                fi;
        fi;
    else
        echo "Update Sun ONE Web Server (iPlanet) configuration for support by WebSphere (yes/no)?"
        read IPLANET_CONFIRM
        if [[ "${IPLANET_CONFIRM}" = "y" || "${IPLANET_CONFIRM}" = "yes" || "${IPLANET_CONFIRM}" = "Y" || "${IPLANET_CONFIRM}" = "Yes" || "${IPLANET_CONFIRM}" = "YES" ]] ; then
            ORIG_IPLANET=$IPLANET_HOME
            while true
            do
                IPLANET_HOME=$ORIG_IPLANET
                if [[ "$IPLANET_HOME" != "" ]] ; then
                    echo "'IPLANET_HOME' is set to: $IPLANET_HOME"
                    echo
                    echo "Use this Sun ONE Web Server (iPlanet) configuration path [y/n]?"
                    read CONFIRM_HOME
                    if [[ "${CONFIRM_HOME}" = "y" || "${CONFIRM_HOME}" = "yes" || "${CONFIRM_HOME}" = "Y" || "${CONFIRM_HOME}" = "Yes" || "${CONFIRM_HOME}" = "YES" ]] ; then
                        echo "The user accepted the path stored in 'IPLANET_HOME'."
                        echo "[$IPLANET_HOME]"
                        echo
                    else
                        echo "The user did not accept the Sun ONE Web Server (iPlanet) path"
                        echo "[$IPLANET_PATH]"
                        echo
                        
                        IPLANET_HOME=
                    fi;
                fi;
                
                if [[ "$IPLANET_HOME" = "" ]] ; then
                    echo
                    echo "Enter the Sun ONE Web Server (iPlanet) configuration home:"
                    echo "Example: /usr/iplanet/servers/https-<hostname>/config"
                    read IPLANET_HOME
                fi;
                
                if [[ ! -f "$IPLANET_HOME/obj.conf" ]] ; then
                    echo "The path specified in 'IPLANET_HOME' is not a valid directory:"
                    echo "[$IPLANET_HOME]"
                    IPLANET_HOME=
                    
                    echo "Cancel this update [y/n]?"
                    read CANCEL_HOME
                    if [[ "${CANCEL_HOME}" = "y" || "${CANCEL_HOME}" = "yes" || "${CANCEL_HOME}" = "Y" || "${CANCEL_HOME}" = "Yes" || "${CANCEL_HOME}" = "YES" ]] ; then
                       exit
                    fi;
                else
                    echo "The path specified in 'IPLANET_HOME' is a valid directory:"
                    echo "[$IPLANET_HOME]"
                    echo
                    break;
                fi;
                
                if [[ "$IPLANET_HOME" = "" ]] ; then
                    echo
                    echo "Update the Sun ONE Web Server (iPlanet) for WebSphere 3.5.7 support [y/n]?"
                    read IPLANET_UPDATE
                    if [[ ! "${IPLANET_UPDATE}" = "y" && ! "${IPLANET_UPDATE}" = "yes" && ! "${IPLANET_UPDATE}" = "Y" && ! "${IPLANET_UPDATE}" = "Yes" && ! "${IPLANET_UPDATE}" = "YES" ]] ; then
                        IPLANET_HOME=
                        IPLANET=
                        break;
                    fi;
                fi;
            done
            
            if [ "$IPLANET_HOME" != "" ]; then
                ORIG_VERSION=$IPLANET_VERSION
                while true
                do 
                    IPLANET_VERSION=$ORIG_VERSION
                    echo
                    echo "Please enter the version number of the Sun ONE Web Server (iPlanet)"
                    echo "to be updated.  Enter '4' for an Sun ONE Web Server (iPlanet)"
                    echo "version 4.x.x or '6' for an Sun ONE Web Server (iPlanet) 6.x.x version:"
                    read IPLANET_VERSION                          
                    
                    if [[ "$IPLANET_VERSION" = "4" ]] ; then
                        echo
                        echo "IPLANET_VERSION is valid."
                        echo
                        IPLANET="$WAS_DIR $IPLANET_HOME $IPLANET_VERSION false"
                        break;
                    elif [[ "$IPLANET_VERSION" = "6" ]] ; then
                        echo "IPLANET_VERSION is valid."
                        echo
                        IPLANET="$WAS_DIR $IPLANET_HOME $IPLANET_VERSION false"
                        break;
                    else
                        echo "The value specified for IPLANET_VERSION"
                        echo "is not 4 or 6, the value is: $IPLANET_VERSION"
                        echo
                    
                        echo "Cancel this update [y/n]?"
                        read CANCEL_VERSION
                        if [[ "${CANCEL_VERSION}" = "y" || "${CANCEL_VERSION}" = "yes" || "${CANCEL_VERSION}" = "Y" || "${CANCEL_VERSION}" = "Yes" || "${CANCEL_VERSION}" = "YES" ]] ; then
                           exit
                        fi;
                    fi;
                done
                    
                echo "The Sun ONE Web Server (iPlanet) will be updated per user request."
                echo
                
                if [[ ! -f "$WAS_DIR/IPlanet6Support.class" ]] ; then
                    if [[ ! -f "was35_adv_ptf_7.jar" ]] ; then
                        echo "The was35_adv_ptf_7.jar file must be in the same directory as the install.sh file."
                        echo
                    else
                        echo "Extracting IPlanet6Support.class"
                        jar -xf was35_adv_ptf_7.jar IPlanet6Support.class
                        cp "IPlanet6Support.class" "$WAS_DIR/IPlanet6Support.class"
                        echo "WAS_DIR: $WAS_DIR" 
                        java -classpath $WAS_DIR IPlanet6Support $IPLANET
                        rm -f $WAS_DIR/IPlanet6Support.class
                    fi;
                else
                    java -classpath $WAS_DIR IPlanet6Support $IPLANET
                    rm -f $WAS_DIR/IPlanet6Support.class
                fi;
            else
                echo "Update of Sun ONE Web Server (iPlanet) will not occur per user request."
                echo
                IPLANET=
            fi;
        else
            echo "Update of Sun ONE Web Server (iPlanet) will not occur per user request."
            echo
            IPLANET=
        fi;    
    fi;
;;
esac

#Installing the IHS PTF
if [[ "$SILENT_INSTALL" = "false" ]] ; then
  if [[ "$IHS_INSTALL" = "true" ]] ; then
	while :
	do
	{
        echo "WARNING: If you install the IBM HTTP Server PTF, the back level of IHS may not work properly with the new level of GSkit."
	  echo "Please enter whether you want to install IHS WebServer PTF (y/n)"
	  read IHS_INSTALL
	  if [[ "${IHS_INSTALL}" = "" ]]
	  then
		continue
	  fi
  
	  if [[ "$IHS_INSTALL" != "y" && "$IHS_INSTALL" != "n" ]]
	  then
		 {
			echo
			echo "Please enter y for Yes or n for No"
			echo 
			continue
		 }
	  elif [[ "$IHS_INSTALL" = "y" ]] ; then
		IHS_INSTALL="true"
	  else
		IHS_INSTALL="false"
	  fi

	  break
	}
	done
  fi
fi

if [[ "$IHS_INSTALL" = "true" ]] ; then
   echo "Installing IHS PTF"
   
   if [[ "$SILENT_INSTALL" = "true" ]] ; then
      java -jar $IHS_PTF -TargetDir $IHS_DIR -backupJar $WAS_DIR/$IHS_BACKUP_JAR -log $WAS_DIR/logs/$IHS_LOG_FILE -SkipVer -OverWriteBackupJar
   else
      java -jar $IHS_PTF -TargetDir $IHS_DIR -backupJar $WAS_DIR/$IHS_BACKUP_JAR -log $WAS_DIR/logs/$IHS_LOG_FILE -SkipVer
   fi

   if [[ $? -ne 0 ]] ; then
      echo "Either the user has chosen to exit, or there was an error "
      echo "during the IBM HTTP Server PTF upgrade."
      echo "In case of error, run uninstall_ptf_#.sh to back out the changes."
      exit
   fi

   echo "Installing the gskit package"
   if [[ "$OS_NAME" = "AIX" ]]  ; then
        # PQ62341 Removing line to uninstall the previous GSKIT version
		# echo "Uninstalling previous version of GSkit."
        # installp -u -g gskit.rte
        echo "Installing new version of GSkit."
        installp -acgXd $IHS_DIR all
   elif [[ "$OS_NAME" = "SunOS" || "$OS_NAME" = "Solaris" ]] ; then
        echo "Installing new version of GSkit."
        pkgadd -a admin -d $IHS_DIR all
   elif [[ "$OS_NAME" = "HP-UX" ]] ; then
        echo "Uninstalling previous version of GSkit."
        /usr/sbin/swremove -x autoselect_dependents=false -x enforce_dependencies=false gsk4bas
        echo "Installing new version of GSkit."
        /usr/bin/chmod u+x $IHS_DIR/gsk4bas/catalog/gsk4bas/gsk4bas/postinstall
        /usr/bin/chmod u+x $IHS_DIR/gsk4bas/catalog/gsk4bas/gsk4bas/preremove
        /usr/sbin/swreg -l depot $IHS_DIR/gsk4bas
        /usr/sbin/swinstall -s $IHS_DIR/gsk4bas gsk4bas 
   elif [[ "$OS_NAME" = "Linux" ]] ; then
	if [[ "${GS_VERSION}" != "" ]]
	then
		rpm -e --nodeps $GS_VERSION
		rpm -ivh gsk4bas*.rpm
	else
		echo "GSkit not currently installed."
		echo "GSkit will not be updated."
	fi
   fi 
   
fi


# Update the samples in the Webservers doc root
if [[ "$SILENT_INSTALL" = "false" ]] ; then
  while :
  do
  {

     echo "In order to update the WebSphere Application Server Samples"
     echo "the currently configured WebServer's doc root must be specified" 
     echo "or press enter to skip upgrading the samples."
     echo "Eg. $EXAMPLE_DOC_ROOT"
     echo "Please enter your webserver's doc root path" 
     read DOC_ROOT
	if [[ "${DOC_ROOT}" = "" ]]
	then
	   break
	fi

	echo "Is this correct (y/n): $DOC_ROOT"
	read CONFIRM
	if [[ "$CONFIRM" != "y"  ]]
	then
		 {
			echo
			echo "Please enter y for Yes or n for No"
			echo 
			continue
		 }
	 fi
       if [[ ! -d $DOC_ROOT ]] ; then
          echo "No such directory: $DOC_ROOT"
          echo " " 
          continue 
       fi

	 break
  }
  done
else
   if [[ "$DOC_ROOT" != "" ]] ; then
     CONFIRM="y"
   fi 
fi

if [[ "$CONFIRM" = "y" ]] ; then
  if [[ "$OS_NAME" = "Linux" ]]  ; then
    cp -pRf $WAS_DIR/WSsamplesIDB $DOC_ROOT
    cp -pRf $WAS_DIR/WSsamples $DOC_ROOT
    cp -pRf $WAS_DIR/theme $DOC_ROOT
    chmod -R 755 $DOC_ROOT  
  else
    cp -pR $WAS_DIR/WSsamplesIDB $DOC_ROOT
    cp -pR $WAS_DIR/WSsamples $DOC_ROOT
    cp -pR $WAS_DIR/theme $DOC_ROOT
    chmod -R 755 $DOC_ROOT  
  fi
fi

#End install 
